package com.chelvc.framework.base.interceptor;

import org.springframework.core.MethodParameter;
import org.springframework.web.context.request.NativeWebRequest;

/**
 * 响应结果处理器接口
 *
 * @author Woody
 * @date 2024/1/30
 */
public interface ResponseHandler {
    /**
     * 判断当前处理器是否支持指定方法
     *
     * @param method 请求方法
     * @return true/false
     */
    default boolean supports(MethodParameter method) {
        return true;
    }

    /**
     * 响应结果处理
     *
     * @param request 请求对象
     * @param method  请求方法
     * @param value   请求结果
     * @return 处理后结果
     */
    Object handle(NativeWebRequest request, MethodParameter method, Object value);
}
